@@ -20,24 +20,23 @@ class DisputesApi(BaseApi):
                       location_id=None):
         """Does a GET request to /v2/disputes.
 
-        Returns a list of disputes associated
-        with a particular account.
+        Returns a list of disputes associated with a particular account.
 
         Args:
             cursor (string, optional): A pagination cursor returned by a
-                previous call to this endpoint. Provide this to retrieve the
-                next set of results for the original query. For more
-                information, see
-                [Paginating](https://developer.squareup.com/docs/basics/api101/
+                previous call to this endpoint. Provide this cursor to
+                retrieve the next set of results for the original query. For
+                more information, see
+                [Pagination](https://developer.squareup.com/docs/basics/api101/
                 pagination).
             states (DisputeState, optional): The dispute states to filter the
                 result. If not specified, the endpoint returns all open
-                disputes (dispute status is not `INQUIRY_CLOSED`, `WON`, or
-                `LOST`).
+                disputes (the dispute status is not `INQUIRY_CLOSED`, `WON`,
+                or `LOST`).
             location_id (string, optional): The ID of the location for which
-                to return  a list of disputes. If not specified, the endpoint
-                returns all open disputes (dispute status is not
-                `INQUIRY_CLOSED`, `WON`, or  `LOST`) associated with all
+                to return a list of disputes. If not specified, the endpoint
+                returns all open disputes (the dispute status is not
+                `INQUIRY_CLOSED`, `WON`, or `LOST`) associated with all
                 locations.
 
         Returns:
@@ -89,7 +88,7 @@ class DisputesApi(BaseApi):
                          dispute_id):
         """Does a GET request to /v2/disputes/{dispute_id}.
 
-        Returns details of a specific dispute.
+        Returns details about a specific dispute.
 
         Args:
             dispute_id (string): The ID of the dispute you want more details
@@ -138,15 +137,16 @@ class DisputesApi(BaseApi):
                        dispute_id):
         """Does a POST request to /v2/disputes/{dispute_id}/accept.
 
-        Accepts loss on a dispute. Square returns
-        the disputed amount to the cardholder and updates the
-        dispute state to ACCEPTED.
-        Square debits the disputed amount from the seller’s Square
-        account. If the Square account balance does not have
-        sufficient funds, Square debits the associated bank account.
+        Accepts the loss on a dispute. Square returns the disputed amount to
+        the cardholder and
+        updates the dispute state to ACCEPTED.
+        Square debits the disputed amount from the seller’s Square account. If
+        the Square account
+        does not have sufficient funds, Square debits the associated bank
+        account.
 
         Args:
-            dispute_id (string): ID of the dispute you want to accept.
+            dispute_id (string): The ID of the dispute you want to accept.
 
         Returns:
             ApiResponse: An object with the response value as well as other
@@ -241,8 +241,8 @@ class DisputesApi(BaseApi):
         """Does a DELETE request to /v2/disputes/{dispute_id}/evidence/{evidence_id}.
 
         Removes specified evidence from a dispute.
-        Square does not send the bank any evidence that
-        is removed. Also, you cannot remove evidence after
+        Square does not send the bank any evidence that is removed. Also, you
+        cannot remove evidence after
         submitting it to the bank using
         [SubmitEvidence](https://developer.squareup.com/docs/reference/square/d
         isputes-api/submit-evidence).
@@ -300,8 +300,8 @@ class DisputesApi(BaseApi):
         Returns the specific evidence metadata associated with a specific
         dispute.
         You must maintain a copy of the evidence you upload if you want to
-        reference it later. You cannot download the evidence
-        after you upload it.
+        reference it later. You cannot
+        download the evidence after you upload it.
 
         Args:
             dispute_id (string): The ID of the dispute that you want to
@@ -355,15 +355,15 @@ class DisputesApi(BaseApi):
         """Does a POST request to /v2/disputes/{dispute_id}/evidence_file.
 
         Uploads a file to use as evidence in a dispute challenge. The endpoint
-        accepts
-        HTTP multipart/form-data file uploads in HEIC, HEIF, JPEG, PDF, PNG,
-        and TIFF formats.
+        accepts HTTP
+        multipart/form-data file uploads in HEIC, HEIF, JPEG, PDF, PNG, and
+        TIFF formats.
 
         Args:
-            dispute_id (string): ID of the dispute you want to upload evidence
-                for.
-            request (CreateDisputeEvidenceFileRequest, optional): Defines
-                parameters for a CreateDisputeEvidenceFile request.
+            dispute_id (string): The ID of the dispute you want to upload
+                evidence for.
+            request (CreateDisputeEvidenceFileRequest, optional): Defines the
+                parameters for a `CreateDisputeEvidenceFile` request.
             image_file (typing.BinaryIO, optional): TODO: type description
                 here.
 
@@ -479,17 +479,16 @@ class DisputesApi(BaseApi):
 
         Submits evidence to the cardholder's bank.
         Before submitting evidence, Square compiles all available evidence.
-        This includes
-        evidence uploaded using the
+        This includes evidence uploaded
+        using the
         [CreateDisputeEvidenceFile](https://developer.squareup.com/docs/referen
         ce/square/disputes-api/create-dispute-evidence-file) and
         [CreateDisputeEvidenceText](https://developer.squareup.com/docs/referen
-        ce/square/disputes-api/create-dispute-evidence-text) endpoints,
-        and evidence automatically provided by Square, when
-        available.
+        ce/square/disputes-api/create-dispute-evidence-text) endpoints and
+        evidence automatically provided by Square, when available.
 
         Args:
-            dispute_id (string): The ID of the dispute you want to submit
+            dispute_id (string): The ID of the dispute that you want to submit
                 evidence for.
 
         Returns:
