@@ -114,8 +114,8 @@ class OAuthApi(BaseApi):
         ```
         Replace `APPLICATION_SECRET` with the application secret on the
         Credentials
-        page in the [application
-        dashboard](https://connect.squareup.com/apps).
+        page in the [Developer
+        Dashboard](https://developer.squareup.com/apps).
 
         Args:
             body (RevokeTokenRequest): An object containing the fields to POST
@@ -169,9 +169,6 @@ class OAuthApi(BaseApi):
         tokens.
         Applications specify a method by adding the `grant_type` parameter
         in the request and also provide relevant information.
-        For more information, see [OAuth access token
-        management](https://developer.squareup.com/docs/authz/oauth/how-it-work
-        s#oauth-access-token-management).
         __Note:__ Regardless of the method application specified,
         the endpoint always returns two items; an OAuth access token and
         a refresh token in the response.
