@@ -32,7 +32,8 @@ class OrdersApi(BaseApi):
                 field details.
 
         Returns:
-            CreateOrderResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -81,7 +82,8 @@ class OrdersApi(BaseApi):
                 definition for field details.
 
         Returns:
-            BatchRetrieveOrdersResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -128,7 +130,8 @@ class OrdersApi(BaseApi):
                 for field details.
 
         Returns:
-            CalculateOrderResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -195,7 +198,8 @@ class OrdersApi(BaseApi):
                 for field details.
 
         Returns:
-            SearchOrdersResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -230,6 +234,54 @@ class OrdersApi(BaseApi):
         _result = ApiResponse(_response, body=decoded, errors=_errors)
         return _result
 
+    def retrieve_order(self,
+                       order_id):
+        """Does a GET request to /v2/orders/{order_id}.
+
+        Retrieves an [Order](#type-order) by ID.
+
+        Args:
+            order_id (string): The ID of the order to retrieve.
+
+        Returns:
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+
+        # Prepare query URL
+        _url_path = '/v2/orders/{order_id}'
+        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
+            'order_id': {'value': order_id, 'encode': True}
+        })
+        _query_builder = self.config.get_base_uri()
+        _query_builder += _url_path
+        _query_url = APIHelper.clean_url(_query_builder)
+
+        # Prepare headers
+        _headers = {
+            'accept': 'application/json'
+        }
+
+        # Prepare and execute request
+        _request = self.config.http_client.get(_query_url, headers=_headers)
+        OAuth2.apply(self.config, _request)
+        _response = self.execute_request(_request)
+
+        decoded = APIHelper.json_deserialize(_response.text)
+        if type(decoded) is dict:
+            _errors = decoded.get('errors')
+        else:
+            _errors = None
+        _result = ApiResponse(_response, body=decoded, errors=_errors)
+        return _result
+
     def update_order(self,
                      order_id,
                      body):
@@ -263,7 +315,8 @@ class OrdersApi(BaseApi):
                 field details.
 
         Returns:
-            UpdateOrderResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -276,7 +329,7 @@ class OrdersApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/orders/{order_id}'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'order_id': order_id
+            'order_id': {'value': order_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -333,7 +386,8 @@ class OrdersApi(BaseApi):
                 field details.
 
         Returns:
-            PayOrderResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -346,7 +400,7 @@ class OrdersApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/orders/{order_id}/pay'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'order_id': order_id
+            'order_id': {'value': order_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
