@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-from deprecation import deprecated
 from square.api_helper import APIHelper
 from square.http.api_response import ApiResponse
 from square.api.base_api import BaseApi
@@ -14,116 +13,6 @@ class V1TransactionsApi(BaseApi):
     def __init__(self, config, call_back=None):
         super(V1TransactionsApi, self).__init__(config, call_back)
 
-    @deprecated()
-    def list_bank_accounts(self,
-                           location_id):
-        """Does a GET request to /v1/{location_id}/bank-accounts.
-
-        Provides non-confidential details for all of a location's associated
-        bank accounts. This endpoint does not provide full bank account
-        numbers, and there is no way to obtain a full bank account number with
-        the Connect API.
-
-        Args:
-            location_id (string): The ID of the location to list bank accounts
-                for.
-
-        Returns:
-            ApiResponse: An object with the response value as well as other
-                useful information such as status codes and headers. Success
-
-        Raises:
-            APIException: When an error occurs while fetching the data from
-                the remote API. This exception includes the HTTP Response
-                code, an error message, and the HTTP body that was received in
-                the request.
-
-        """
-
-        # Prepare query URL
-        _url_path = '/v1/{location_id}/bank-accounts'
-        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'location_id': {'value': location_id, 'encode': True}
-        })
-        _query_builder = self.config.get_base_uri()
-        _query_builder += _url_path
-        _query_url = APIHelper.clean_url(_query_builder)
-
-        # Prepare headers
-        _headers = {
-            'accept': 'application/json'
-        }
-
-        # Prepare and execute request
-        _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
-        _response = self.execute_request(_request)
-
-        decoded = APIHelper.json_deserialize(_response.text)
-        if type(decoded) is dict:
-            _errors = decoded.get('errors')
-        else:
-            _errors = None
-        _result = ApiResponse(_response, body=decoded, errors=_errors)
-        return _result
-
-    @deprecated()
-    def retrieve_bank_account(self,
-                              location_id,
-                              bank_account_id):
-        """Does a GET request to /v1/{location_id}/bank-accounts/{bank_account_id}.
-
-        Provides non-confidential details for a merchant's associated bank
-        account. This endpoint does not provide full bank account numbers, and
-        there is no way to obtain a full bank account number with the Connect
-        API.
-
-        Args:
-            location_id (string): The ID of the bank account's associated
-                location.
-            bank_account_id (string): The bank account's Square-issued ID. You
-                obtain this value from Settlement objects returned.
-
-        Returns:
-            ApiResponse: An object with the response value as well as other
-                useful information such as status codes and headers. Success
-
-        Raises:
-            APIException: When an error occurs while fetching the data from
-                the remote API. This exception includes the HTTP Response
-                code, an error message, and the HTTP body that was received in
-                the request.
-
-        """
-
-        # Prepare query URL
-        _url_path = '/v1/{location_id}/bank-accounts/{bank_account_id}'
-        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'location_id': {'value': location_id, 'encode': True},
-            'bank_account_id': {'value': bank_account_id, 'encode': True}
-        })
-        _query_builder = self.config.get_base_uri()
-        _query_builder += _url_path
-        _query_url = APIHelper.clean_url(_query_builder)
-
-        # Prepare headers
-        _headers = {
-            'accept': 'application/json'
-        }
-
-        # Prepare and execute request
-        _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
-        _response = self.execute_request(_request)
-
-        decoded = APIHelper.json_deserialize(_response.text)
-        if type(decoded) is dict:
-            _errors = decoded.get('errors')
-        else:
-            _errors = None
-        _result = ApiResponse(_response, body=decoded, errors=_errors)
-        return _result
-
     def list_orders(self,
                     location_id,
                     order=None,
@@ -136,7 +25,7 @@ class V1TransactionsApi(BaseApi):
         Args:
             location_id (string): The ID of the location to list online store
                 orders for.
-            order (SortOrder, optional): TThe order in which payments are
+            order (SortOrder, optional): The order in which payments are
                 listed in the response.
             limit (int, optional): The maximum number of payments to return in
                 a single response. This value cannot exceed 200.
@@ -472,7 +361,7 @@ class V1TransactionsApi(BaseApi):
 
         Args:
             location_id (string): The ID of the location to list refunds for.
-            order (SortOrder, optional): TThe order in which payments are
+            order (SortOrder, optional): The order in which payments are
                 listed in the response.
             begin_time (string, optional): The beginning of the requested
                 reporting period, in ISO 8601 format. If this value is before
